@@ -74,8 +74,8 @@ ATTACHMENT_INTERPOLATION_HEADER = getattr(
 
 
 class ActiveMailboxManager(models.Manager):
-    def get_query_set(self):
-        return super(ActiveMailboxManager, self).get_query_set().filter(
+    def get_queryset(self):
+        return super(ActiveMailboxManager, self).get_queryset().filter(
             active=True,
         )
 
@@ -351,22 +351,22 @@ class Mailbox(models.Model):
 
 
 class IncomingMessageManager(models.Manager):
-    def get_query_set(self):
-        return super(IncomingMessageManager, self).get_query_set().filter(
+    def get_queryset(self):
+        return super(IncomingMessageManager, self).get_queryset().filter(
             outgoing=False,
         )
 
 
 class OutgoingMessageManager(models.Manager):
-    def get_query_set(self):
-        return super(OutgoingMessageManager, self).get_query_set().filter(
+    def get_queryset(self):
+        return super(OutgoingMessageManager, self).get_queryset().filter(
             outgoing=True,
         )
 
 
 class UnreadMessageManager(models.Manager):
-    def get_query_set(self):
-        return super(UnreadMessageManager, self).get_query_set().filter(
+    def get_queryset(self):
+        return super(UnreadMessageManager, self).get_queryset().filter(
             read=None
         )
 
